#
# spec file for package ghc-monad-control
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name monad-control
Name:           ghc-%{pkg_name}
Version:        1.0.2.3
Release:        lp151.1.2
Summary:        Lift control operations, like exception catching, through monad transformers
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel

%description
This package defines the type class 'MonadBaseControl', a subset of 'MonadBase'
into which generic control operations such as 'catch' can be lifted from 'IO'
or any other base monad. Instances are based on monad transformers in
'MonadTransControl', which includes all standard monad transformers in the
'transformers' library except 'ContT'.

See the <http://hackage.haskell.org/package/lifted-base lifted-base> package
which uses 'monad-control' to lift 'IO' operations from the 'base' library
(like 'catch' or 'bracket') into any monad that is an instance of 'MonadBase'
or 'MonadBaseControl'.

Note that this package is a rewrite of Anders Kaseorg's 'monad-peel' library.
The main difference is that this package provides CPS style operators and
exploits the 'RankNTypes' and 'TypeFamilies' language extensions to simplify
and speedup most definitions.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README.markdown

%changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update monad-control to version 1.0.2.3.
  * Correct spelling mistake. Courtesy of Edward Betts.
  * Support transformers-compat-0.6.
  * Added some good documentation. Courtesy of Franz Thoma.
* Tue Jul 11 2017 psimons@suse.com
- Update to version 1.0.2.1.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 1.0.2.0.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.0.1.0 revision 0 with cabal2obs.
* Thu Apr  7 2016 mimi.vx@gmail.com
- update to 1.0.1.0
- removed useless _service
  * Added the functions:
  liftThrough
    :: (MonadTransControl t, Monad (t m), Monad m)
    => (m (StT t a) -> m (StT t b)) -- ^
  - > t m a -> t m b
  captureT :: (MonadTransControl t, Monad (t m), Monad m) => t m (StT t ())
  captureM :: MonadBaseControl b m => m (StM m ())
* Fri Jan 29 2016 mimi.vx@gmail.com
- update to 1.0.0.5
  * Support transformers-0.5 & ransformers-compat-0.5.*.
* Tue Apr 21 2015 mimi.vx@gmail.com
- update to 1.0.0.4
  * Support transformers-compat-0.4.*.
  * Unconditionally add ExceptT instances using transformers-compat.
  Courtesy of Adam Bergmark.
  * Add a base >= 4.5 constraint because monad-control only builds on GHC >= 7.4.
  * Use Safe instead of Trustworthy.
    This requires a dependency on stm.
  * Switch the associated data types StT and StM to associated type synonyms.
    This is an API breaking change. To fix your MonadTransControl or
    MonadBaseControl instances simply remove the StT or StM constructors
    and deconstructors for your monad transformers or monad.
  * Add the embed, embed_ and liftBaseOpDiscard functions.
  * Support transformers-0.4.0.0
  * Drop unicode syntax and symbols
* Sun Oct  6 2013 sbahling@suse.com
- Initial package - version 0.3.2.1
